@@ -1,4 +1,4 @@
-/*  $Id: Couple.h,v 1.2 2010/04/25 01:15:57 sarrazip Exp $
+/*  $Id: Couple.h,v 1.3 2010/06/05 20:50:42 sarrazip Exp $
     Couple.h - Class representing a couple of integers.
 
     flatzebra - Generic 2D Game Engine library
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #ifndef _H_Couple
@@ -72,6 +72,10 @@ public:
     /*  Returns true iff one or both components differ from zero.
     */
 
+    int squaredLength() const;
+    /*  Returns the square of the length of the vector represented by the couple.
+    */
+
     double length() const;
     /*  Returns the length of the vector represented by the couple.
     */
@@ -91,6 +95,10 @@ public:
     friend bool operator == (const Couple &c1, const Couple &c2);
     friend bool operator != (const Couple &c1, const Couple &c2);
 
+    int dotProduct(const Couple &c) const;
+    /*  Returns the scalar product of this couple with the given one.
+    */
+
 };
 
 
@@ -228,9 +236,21 @@ inline bool operator != (const Couple &c1, const Couple &c2)
 }
 
 
+inline int Couple::squaredLength() const
+{
+    return x * x + y * y;
+}
+
+
 inline double Couple::length() const
 {
-    return sqrt(double(x) * x + double(y) * y);
+    return hypot(x, y);
+}
+
+
+inline int Couple::dotProduct(const Couple &c) const
+{
+    return x * c.x + y * c.y;
 }
 
 
